import os

import numpy as np
import pytest

OPENSLIDE_TESTDATA_DIR = os.getenv("OPENSLIDE_TESTDATA_DIR", None)
FILES = {
    "svs": "Aperio/CMU-2.svs",
    "generic": "Generic-TIFF/CMU-1.tiff",
    "hamamatsu": "Hamamatsu/OS-3.ndpi",
    "leica": "Leica/Leica-2.scn",
    "ventana": "Ventana/OS-2.bif",
}
if OPENSLIDE_TESTDATA_DIR is None:
    pytestmark = pytest.mark.skip

else:
    pytestmark = pytest.mark.compat  # type: ignore

    for key, fn in FILES.items():
        FILES[key] = os.path.join(OPENSLIDE_TESTDATA_DIR, fn)


MODULES = ["tiffslide", "openslide"]


@pytest.fixture(params=list(FILES))
def file_name(request):
    yield FILES[request.param]


@pytest.fixture()
def ts_slide(file_name):
    from tiffslide import TiffSlide

    yield TiffSlide(file_name)


@pytest.fixture()
def os_slide(file_name):
    from openslide import OpenSlide

    yield OpenSlide(file_name)


def test_dimensions(ts_slide, os_slide):
    assert ts_slide.dimensions == os_slide.dimensions


def test_level_count(ts_slide, os_slide):
    assert ts_slide.level_count == os_slide.level_count


def test_level_dimensions(ts_slide, os_slide):
    assert ts_slide.level_dimensions == os_slide.level_dimensions


def test_level_downsamples(ts_slide, os_slide):
    np.testing.assert_allclose(ts_slide.level_downsamples, os_slide.level_downsamples)



# This setup.py file is just needed to support editable installs via
# `pip install -e .` and `python setup.py develop`
#
# NOTE:
#   If you want an editable install `python setup.py develop` should
#   not be used and you should always use `pip install -e .`
#   But, it's almost guaranteed that some user will install via
#   the former, and so let's make setuptools_scm work correctly
#   in that case.
#
from setuptools import setup

setup(
    # providing the settings is required for `python setup.py develop`
    # to work correctly with setuptools_scm
    # > set to `True` if we only allow `pip install -e .`
    # ^^^ `True` requires a pyproject.toml with the below config!
    use_scm_version={
        # duplicated config from pyproject.toml; keep in sync
        "write_to": "tiffslide/_version.py",
        "version_scheme": "post-release",
    },
    setup_requires=["setuptools_scm"],
)
